==> jc-1.4.0.tar.gz: javax/imageio/spi/IIOServiceProvider.h <==
// public abstract class javax.imageio.spi.IIOServiceProvider

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_spi_IIOServiceProvider_H_
#define _JC_javax_imageio_spi_IIOServiceProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;
struct _jc_javax_imageio_spi_ServiceRegistry$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	_jc_javax_imageio_spi_IIOServiceProvider$sub_refs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	_jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$refs	_jc_javax_imageio_spi_IIOServiceProvider$refs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$nonrefs	_jc_javax_imageio_spi_IIOServiceProvider$nonrefs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$object	_jc_javax_imageio_spi_IIOServiceProvider$object;

typedef const struct _jc_javax_imageio_spi_IIOServiceProvider$vmethods	_jc_javax_imageio_spi_IIOServiceProvider$vmethods;
typedef const struct _jc_javax_imageio_spi_IIOServiceProvider$vtable	_jc_javax_imageio_spi_IIOServiceProvider$vtable;
typedef const struct _jc_javax_imageio_spi_IIOServiceProvider$vtype	_jc_javax_imageio_spi_IIOServiceProvider$vtype;

// Constructors
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *);
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_IIOServiceProvider$method$getDescription$e653ca2170cc9e26(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_java_util_Locale$object *);
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_IIOServiceProvider$method$getVendorName$30bf90a8d303e238(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *);
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_IIOServiceProvider$method$getVersion$fd161b85df36e54b(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *);
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$onDeregistration$8e102f4596ea784f(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *);
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$onRegistration$a88ca38be7f0b762(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$getDescription$e653ca2170cc9e26;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$getVendorName$30bf90a8d303e238;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$getVersion$fd161b85df36e54b;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$onDeregistration$8e102f4596ea784f;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$onRegistration$a88ca38be7f0b762;

// Virtual methods structure
struct _jc_javax_imageio_spi_IIOServiceProvider$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$e653ca2170cc9e26)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_java_util_Locale$object *);
	struct _jc_java_lang_String$object	*(*getVendorName$30bf90a8d303e238)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *);
	struct _jc_java_lang_String$object	*(*getVersion$fd161b85df36e54b)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *);
	void	(*onDeregistration$8e102f4596ea784f)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *);
	void	(*onRegistration$a88ca38be7f0b762)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *);
};

// Vtable
struct _jc_javax_imageio_spi_IIOServiceProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
};

// Vtype
struct _jc_javax_imageio_spi_IIOServiceProvider$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_IIOServiceProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIOServiceProvider$sub_refs {
	struct _jc_java_lang_String$object	*vendorName;
	struct _jc_java_lang_String$object	*version;
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_IIOServiceProvider$refs {
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_IIOServiceProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
};

// Object instance structure
struct _jc_javax_imageio_spi_IIOServiceProvider$object {
	_jc_javax_imageio_spi_IIOServiceProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_IIOServiceProvider$vtype	*vtype;
	_jc_javax_imageio_spi_IIOServiceProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_IIOServiceProvider$vtype _jc_javax_imageio_spi_IIOServiceProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_IIOServiceProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_IIOServiceProvider$class_object;

#endif	/* _JC_javax_imageio_spi_IIOServiceProvider_H_ */

==> jc-1.4.6.tar.gz: javax/imageio/spi/IIOServiceProvider.h <==
// public abstract class javax.imageio.spi.IIOServiceProvider

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_imageio_spi_IIOServiceProvider_H_
#define _JC_javax_imageio_spi_IIOServiceProvider_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;
struct _jc_javax_imageio_spi_ServiceRegistry$object;

// Typedefs
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	_jc_javax_imageio_spi_IIOServiceProvider$sub_refs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	_jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$refs	_jc_javax_imageio_spi_IIOServiceProvider$refs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$nonrefs	_jc_javax_imageio_spi_IIOServiceProvider$nonrefs;
typedef struct _jc_javax_imageio_spi_IIOServiceProvider$object	_jc_javax_imageio_spi_IIOServiceProvider$object;

typedef const struct _jc_javax_imageio_spi_IIOServiceProvider$vmethods	_jc_javax_imageio_spi_IIOServiceProvider$vmethods;
typedef const struct _jc_javax_imageio_spi_IIOServiceProvider$vtable	_jc_javax_imageio_spi_IIOServiceProvider$vtable;
typedef const struct _jc_javax_imageio_spi_IIOServiceProvider$vtype	_jc_javax_imageio_spi_IIOServiceProvider$vtype;

// Constructors
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$_init$a34354cd9552963f(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_IIOServiceProvider$method$getDescription$e653ca2170cc9e26(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_IIOServiceProvider$method$getVendorName$30bf90a8d303e238(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_javax_imageio_spi_IIOServiceProvider$method$getVersion$fd161b85df36e54b(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$onDeregistration$8e102f4596ea784f(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern void _jc_javax_imageio_spi_IIOServiceProvider$method$onRegistration$a88ca38be7f0b762(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$getDescription$e653ca2170cc9e26;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$getVendorName$30bf90a8d303e238;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$getVersion$fd161b85df36e54b;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$onDeregistration$8e102f4596ea784f;
extern _jc_method _jc_javax_imageio_spi_IIOServiceProvider$method_info$onRegistration$a88ca38be7f0b762;

// Virtual methods structure
struct _jc_javax_imageio_spi_IIOServiceProvider$vmethods {
	struct _jc_java_lang_String$object	*(*getDescription$e653ca2170cc9e26)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getVendorName$30bf90a8d303e238)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getVersion$fd161b85df36e54b)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *) _JC_JCNI_ATTR;
	void	(*onDeregistration$8e102f4596ea784f)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	void	(*onRegistration$a88ca38be7f0b762)(_jc_env *, struct _jc_javax_imageio_spi_IIOServiceProvider$object *, struct _jc_javax_imageio_spi_ServiceRegistry$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_imageio_spi_IIOServiceProvider$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
};

// Vtype
struct _jc_javax_imageio_spi_IIOServiceProvider$vtype {
	_jc_type			type;
	_jc_javax_imageio_spi_IIOServiceProvider$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIOServiceProvider$sub_refs {
	struct _jc_java_lang_String$object	*vendorName;
	struct _jc_java_lang_String$object	*version;
};

// Reference instance fields (object)
struct _jc_javax_imageio_spi_IIOServiceProvider$refs {
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_imageio_spi_IIOServiceProvider$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
};

// Object instance structure
struct _jc_javax_imageio_spi_IIOServiceProvider$object {
	_jc_javax_imageio_spi_IIOServiceProvider$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_imageio_spi_IIOServiceProvider$vtype	*vtype;
	_jc_javax_imageio_spi_IIOServiceProvider$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_imageio_spi_IIOServiceProvider$vtype _jc_javax_imageio_spi_IIOServiceProvider$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_imageio_spi_IIOServiceProvider, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_imageio_spi_IIOServiceProvider$class_object;

#endif	/* _JC_javax_imageio_spi_IIOServiceProvider_H_ */
